//! Generated code of flatbuffers (.fbs) in [format](https://github.com/apache/arrow/tree/master/format)
#![allow(non_camel_case_types)]
#![allow(non_snake_case)]

#[allow(clippy::all)]
pub mod File;
#[allow(clippy::all)]
pub mod Message;
#[allow(clippy::all)]
pub mod Schema;
#[allow(clippy::all)]
pub mod SparseTensor;
#[allow(clippy::all)]
pub mod Tensor;

/// Re-export of flatbuffers
pub use ::flatbuffers;
